from flask import redirect, url_for, request, flash
from flask_login import login_required, current_user
from app import app, db
from app.forms.account import UpdateAccountForm, RegistrationForm
from app.models.users import Member
from app.utils.render import render

@app.route('/account', methods=['GET', 'POST'])
@login_required
def account():
    form = UpdateAccountForm()
    if request.method == "POST":
        if form.validate_on_submit():
            current_user.update(
                email=      form.email.data,
                password=   form.password.data,
                signature=  form.signature.data,
                bio=        form.biography.data,
                birthday=   form.birthday.data,
                newsletter= form.newsletter.data
            )
            db.session.add(current_user)
            db.session.commit()
            flash('Modifications effectuées', 'ok')
        else:
            flash('Erreur lors de la modification', 'error')
    return render('account.html', form=form)

@app.route('/register', methods=['GET', 'POST'])
def register():
    if current_user.is_authenticated:
        return redirect(url_for('index'))
    form = RegistrationForm()
    if form.validate_on_submit():
        member = Member(form.username.data, form.email.data, form.password.data)
        db.session.add(member)
        db.session.commit()
        flash('Inscription réussie', 'ok')
        return redirect(url_for('validation'))
    return render('register.html', title='Register', form=form)

@app.route('/register/validation/')
def validation():
    if current_user.is_authenticated :
        return redirect(url_for('index'))
    return render('validation.html')
